@@ -2,5 +2,8 @@ from lelof1py.definitions import *
 from lelof1py.register import *
 from lelof1py.registers import *
 from lelof1py.async_client import *
+from lelof1py.socket_server import *
+from lelof1py.socket_client import *
 from lelof1py.callback_handler import *
 from lelof1py.helpers import *
+from lelof1py.fs_utils import *
